==> aws-cdk.aws-cloudformation-1.27.0.tar.gz: aws-cdk.aws-cloudformation-1.27.0/setup.py <==
import json
import setuptools

kwargs = json.loads("""
{
    "name": "aws-cdk.aws-cloudformation",
    "version": "1.27.0",
    "description": "CDK Constructs for AWS CloudFormation",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_cloudformation",
        "aws_cdk.aws_cloudformation._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_cloudformation._jsii": [
            "aws-cloudformation@1.27.0.jsii.tgz"
        ],
        "aws_cdk.aws_cloudformation": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii~=0.22.0",
        "publication>=0.0.3",
        "aws-cdk.aws-iam==1.27.0",
        "aws-cdk.aws-lambda==1.27.0",
        "aws-cdk.aws-s3==1.27.0",
        "aws-cdk.aws-sns==1.27.0",
        "aws-cdk.core==1.27.0",
        "aws-cdk.cx-api==1.27.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved"
    ]
}
""")

with open('README.md') as fp:
    kwargs['long_description'] = fp.read()


setuptools.setup(**kwargs)

==> aws-cdk.aws-cloudformation-1.38.0.tar.gz: aws-cdk.aws-cloudformation-1.38.0/setup.py <==
import json
import setuptools

kwargs = json.loads("""
{
    "name": "aws-cdk.aws-cloudformation",
    "version": "1.38.0",
    "description": "CDK Constructs for AWS CloudFormation",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_cloudformation",
        "aws_cdk.aws_cloudformation._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_cloudformation._jsii": [
            "aws-cloudformation@1.38.0.jsii.tgz"
        ],
        "aws_cdk.aws_cloudformation": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii>=1.5.0, <2.0.0",
        "publication>=0.0.3",
        "aws-cdk.aws-iam==1.38.0",
        "aws-cdk.aws-lambda==1.38.0",
        "aws-cdk.aws-s3==1.38.0",
        "aws-cdk.aws-sns==1.38.0",
        "aws-cdk.core==1.38.0",
        "aws-cdk.cx-api==1.38.0",
        "constructs>=3.0.2, <4.0.0"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed",
        "Development Status :: 7 - Inactive",
        "License :: OSI Approved"
    ]
}
""")

with open('README.md') as fp:
    kwargs['long_description'] = fp.read()


setuptools.setup(**kwargs)
